@@ -1,6 +1,7 @@
 from contextlib import contextmanager
 from scrapeanything.utils.config import Config
 from scrapeanything.database.repository import Repository
+from scrapeanything.utils.log import Log
 
 @contextmanager
 def Connection(config: Config):
@@ -9,7 +10,9 @@ def Connection(config: Config):
     try:
         yield repository
         repository.commit()
-    except:
+    except Exception as e:
+        Log.error('Error while running database operation: {e}')
         repository.rollback()
+        raise Exception()
     finally:
         repository.close()
\ No newline at end of file
