@@ -258,12 +258,15 @@ class Repository:
     def query(self, entity_type):
         return self.session.query(entity_type)
 
-    def sql(self, query: str, parameters: dict) -> any:
+    def sql(self, query: str, parameters: dict=None, entity_type: any=None) -> any:
         '''
         Executes sql query. Make sure you use :parameter for parameters
         '''
         q = text(query)
-        return self.engine.execute(q, parameters)
+        result = self.engine.execute(q, parameters).all()
+
+        for row in result:
+            pass
 
     def assign(self, entity, prop, value):
         loaded_value = self.load(entity=value)
