@@ -94,8 +94,8 @@ class Selenium(Scraper):
     def on_get_attribute(self, element, prop):
         return element.get_attribute(prop)
 
-    def on_click(self, path, element=None, timeout=0):
-        element = self.on_xPath(path=path, element=element, timeout=timeout)
+    def click(self, path, element=None, timeout=0):
+        element = self.xPath(path=path, element=element, timeout=timeout)
 
         if element is not None:
             if type(element) is list:
